<?php
namespace UP1\AgendaTheses\Controller;

class StartController extends \TYPO3\CMS\Extbase\Mvc\Controller\ActionController
{
    /**
     * Webservice URL from the plugin config.
     *
     * @var string
     */
    protected $wsUrl = '';

    /**
     * Filter for the selected doctoral school
     *
     * @var string
     */
    protected $filterDoctoralSchool = '';

    /**
     * Filter for display thesis or/and hdr
     *
     * @var string
     */
    protected $selectorTheseHdr = '';

    /**
     * Number of thesis to be displayed.
     *
     * @var string
     */
    protected $dataMaxDisplaySettings = '';

    /**
     * Path to the layout if used.
     *
     * @var bool
     */
    protected $disableTemplate = '';

    /**
     * Path to the layout if used.
     *
     * @var string
     */
    protected $layout = '';

    /**
     * Path to the partial if used.
     *
     * @var string
     */
    protected $partial = '';

    /**
     * Path to the template if used.
     *
     * @var string
     */
    protected $template = '';

    /**
     * Array of the datas to be displayed.
     *
     * @var array
     */
    protected $dataToDisplaySettings = array();


    /**
     * Initializes the current action
     *
     * @return void
     */
    public function initializeAction()
    {
        $this->extConf = unserialize($GLOBALS['TYPO3_CONF_VARS']['EXT']['extConf']['agenda_theses']);
        $this->wsUrl = $this->extConf['WsUrl'];

        //Parmètres d'affichage
        $this->dataToDisplaySettings = explode(",",$this->settings['agendaTheses']['dataToDisplay']);
        $this->dataMaxDisplaySettings = $this->settings['agendaTheses']['dataMaxDisplay'];

        //Filtre d'affichage
        $value = $this->settings['agendaTheses']['filtreEcoleDoctorale'];
        if ($value != "")
        {
            $this->filterDoctoralSchool = "(";
            $dataDoctoralSchool = explode(",",$value);
            foreach ($dataDoctoralSchool as $iterator)
            {
                $this->filterDoctoralSchool .= "'".$iterator."',";
            }
            //remove the last ','
            $this->filterDoctoralSchool = substr($this->filterDoctoralSchool,0,-1);
            $this->filterDoctoralSchool .= ")";
        }
        $this->selectorTheseHdr = $this->settings['agendaTheses']['filtreTheseHdr'];

        //Template d'affichage
        $this->disableTemplate = (bool)$this->settings['agendaTheses']['disableTemplate'];
        $this->layout = $this->settings['agendaTheses']['layout'];
        $this->partial = $this->settings['agendaTheses']['partial'];
        $this->template = $this->settings['agendaTheses']['template'];
    }

    /**
     * Index action for this controller.
     *
     * @return string The rendered view
     */
    public function indexAction()
    {
        $Json = new \UP1\AgendaTheses\Domain\Model\Json();
        //set the filter
        $jsonFilter = "?ed=".$this->filterDoctoralSchool."&filter=";
        if($this->selectorTheseHdr == 1)
        {
            $jsonFilter .= "('DOC')";
        }
        if($this->selectorTheseHdr == 2)
        {
            $jsonFilter .= "('HDR')";
        }
        if($this->selectorTheseHdr == 3)
        {
            $jsonFilter .= "('DOC','HDR')";
        }
        $Json->getJsonDatasFromUrl($this->wsUrl.$jsonFilter);
        $Json->transformJsonDatasToArray();

        $Apogee = new \UP1\AgendaTheses\Domain\Model\Apogee();
        $Apogee->transformApogeeDatasArrayToArrayForDisplay($Json->getJsonDatasArray());
        $dataToBeDisplayed = $Apogee->getListThesis($this->selectorTheseHdr);

        if ($this->dataMaxDisplaySettings != "")
        {
            while ($this->dataMaxDisplaySettings < count($dataToBeDisplayed)) {
                @array_pop($dataToBeDisplayed);
            }
        }
        else
        {
            $this->dataMaxDisplaySettings = count($dataToBeDisplayed);
        }

        if ($this->disableTemplate)
        {
            $this->objectManager = \TYPO3\CMS\Core\Utility\GeneralUtility::makeInstance('TYPO3\\CMS\\Extbase\\Object\\ObjectManager');

            $gabaritView = $this->objectManager->get('TYPO3\\CMS\\Fluid\\View\\StandaloneView');
            $gabaritView->setFormat('html');

            $gabaritView->setTemplatePathAndFilename(\TYPO3\CMS\Core\Utility\GeneralUtility::getFileAbsFileName($this->template));
            $gabaritView->setLayoutRootPath(\TYPO3\CMS\Core\Utility\GeneralUtility::getFileAbsFileName($this->layout));
            $gabaritView->setPartialRootPath(\TYPO3\CMS\Core\Utility\GeneralUtility::getFileAbsFileName($this->partial));

            $gabaritView->assign('theses', $dataToBeDisplayed);
            return $gabaritView->render();
        }
        else
        {
            $this->view->assign('theses', $dataToBeDisplayed);
        }
    }

    /**
     * Index action for this controller.
     *
     * @return string The rendered view
     */
    public function showAction()
    {

    }
}

?>